CollectionNotificationTargetQuery class
A query to send a PUSH notification for all tokens in a specific field, with conditions specified for a specific collection.
特定のコレクションに対して条件を指定し特定のフィールドにあるトークンすべてに対してPUSH通知を送信するためのクエリ。
- Inheritance
-
- Object
- NotificationTargetQuery
- CollectionNotificationTargetQuery
Constructors
-
CollectionNotificationTargetQuery({required String collectionPath, required ModelServerCommandField tokenField, List<
ModelServerCommandCondition> wheres = const [], List<ModelServerCommandCondition> conditions = const []}) -
A query to send a PUSH notification for all tokens in a specific field, with conditions specified for a specific collection.
const
Properties
- collectionPath → String
-
Path of the collection from which to retrieve the list of documents to be deleted.
final
-
conditions
→ List<
ModelServerCommandCondition> -
Specify the condition for the acquired data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenField → ModelServerCommandField
-
Key to retrieve a list of eligible tokens.
final
-
wheres
→ List<
ModelServerCommandCondition> -
Specify the conditions for retrieving from the collection.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDatabaseId(
) → String -
Generate a database ID for registration in the schedule.
override
-
toJson(
) → DynamicMap -
Generate Json to pass to the server side.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited