RemoteNotificationScheduleModel class abstract

This model is for scheduling and registering remote PUSH notifications.

Specify the date and time to send the notification in time.

Specify the title of the notification in title. Specify the body of the notification in text.

リモートPUSH通知をスケジュールして登録するためのモデルです。

timeに通知を送信する日時を指定します。

titleに通知のタイトルを指定します。textに通知の本文を指定します。

Implemented types
Available extensions
Annotations
  • @freezed
  • @formValue
  • @immutable
  • @CollectionModelPath.new(SchedulerQuery.path, adapter: "RemoteNotificationMasamuneAdapter.primary.modelAdapter")

Constructors

RemoteNotificationScheduleModel({required ModelServerCommandRemoteNotificationSchedule command})
This model is for scheduling and registering remote PUSH notifications.
const
factory
RemoteNotificationScheduleModel.fromJson(Map<String, Object?> json)
Convert from JSON.
factory

Properties

command ModelServerCommandRemoteNotificationSchedule
no setterinherited
copyWith → $RemoteNotificationScheduleModelCopyWith<RemoteNotificationScheduleModel>
Create a copy of RemoteNotificationScheduleModel with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_RemoteNotificationScheduleModel value)) → TResult

Available on RemoteNotificationScheduleModel, provided by the RemoteNotificationScheduleModelPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_RemoteNotificationScheduleModel value)?) → TResult?

Available on RemoteNotificationScheduleModel, provided by the RemoteNotificationScheduleModelPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_RemoteNotificationScheduleModel value)?, {required TResult orElse()}) → TResult

Available on RemoteNotificationScheduleModel, provided by the RemoteNotificationScheduleModelPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(ModelServerCommandRemoteNotificationSchedule command)?, {required TResult orElse()}) → TResult

Available on RemoteNotificationScheduleModel, provided by the RemoteNotificationScheduleModelPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this RemoteNotificationScheduleModel to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(ModelServerCommandRemoteNotificationSchedule command)) → TResult

Available on RemoteNotificationScheduleModel, provided by the RemoteNotificationScheduleModelPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(ModelServerCommandRemoteNotificationSchedule command)?) → TResult?

Available on RemoteNotificationScheduleModel, provided by the RemoteNotificationScheduleModelPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

collection → const _$RemoteNotificationScheduleModelCollectionQuery
Query for collection.
document → const _$RemoteNotificationScheduleModelDocumentQuery
Query for document.
form → const _$RemoteNotificationScheduleModelFormQuery
Query for form value.